/*
 * Internal module API header file.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtXmlPatternsAPI_H
#define _QtXmlPatternsAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_WebChannel
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QAbstractXmlNodeModel__SimpleAxis 0
#define sipName_QAbstractXmlNodeModel__SimpleAxis &sipStrings_QtXmlPatterns[0]
#define sipNameNr_QXmlNodeModelIndex__DocumentOrder 34
#define sipName_QXmlNodeModelIndex__DocumentOrder &sipStrings_QtXmlPatterns[34]
#define sipNameNr_QXmlNodeModelIndex__NodeKind 68
#define sipName_QXmlNodeModelIndex__NodeKind &sipStrings_QtXmlPatterns[68]
#define sipNameNr_97 97
#define sipName_97 &sipStrings_QtXmlPatterns[97]
#define sipNameNr_QXmlQuery__QueryLanguage 125
#define sipName_QXmlQuery__QueryLanguage &sipStrings_QtXmlPatterns[125]
#define sipNameNr_QAbstractMessageHandler 150
#define sipName_QAbstractMessageHandler &sipStrings_QtXmlPatterns[150]
#define sipNameNr_setNetworkAccessManager 174
#define sipName_setNetworkAccessManager &sipStrings_QtXmlPatterns[174]
#define sipNameNr_setInitialTemplateName 198
#define sipName_setInitialTemplateName &sipStrings_QtXmlPatterns[198]
#define sipNameNr_ProcessingInstruction 221
#define sipName_ProcessingInstruction &sipStrings_QtXmlPatterns[221]
#define sipNameNr_QAbstractXmlNodeModel 243
#define sipName_QAbstractXmlNodeModel &sipStrings_QtXmlPatterns[243]
#define sipNameNr_processingInstruction 265
#define sipName_processingInstruction &sipStrings_QtXmlPatterns[265]
#define sipNameNr_QAbstractUriResolver 287
#define sipName_QAbstractUriResolver &sipStrings_QtXmlPatterns[287]
#define sipNameNr_QAbstractXmlReceiver 308
#define sipName_QAbstractXmlReceiver &sipStrings_QtXmlPatterns[308]
#define sipNameNr_evaluateToStringList 329
#define sipName_evaluateToStringList &sipStrings_QtXmlPatterns[329]
#define sipNameNr_networkAccessManager 350
#define sipName_networkAccessManager &sipStrings_QtXmlPatterns[350]
#define sipNameNr_PyQt5_QtXmlPatterns 371
#define sipName_PyQt5_QtXmlPatterns &sipStrings_QtXmlPatterns[371]
#define sipNameNr_QSimpleXmlNodeModel 391
#define sipName_QSimpleXmlNodeModel &sipStrings_QtXmlPatterns[391]
#define sipNameNr_QXmlSchemaValidator 411
#define sipName_QXmlSchemaValidator &sipStrings_QtXmlPatterns[411]
#define sipNameNr_initialTemplateName 431
#define sipName_initialTemplateName &sipStrings_QtXmlPatterns[431]
#define sipNameNr_setIndentationDepth 451
#define sipName_setIndentationDepth &sipStrings_QtXmlPatterns[451]
#define sipNameNr_QXmlNodeModelIndex 471
#define sipName_QXmlNodeModelIndex &sipStrings_QtXmlPatterns[471]
#define sipNameNr_nextFromSimpleAxis 490
#define sipName_nextFromSimpleAxis &sipStrings_QtXmlPatterns[490]
#define sipNameNr_509 509
#define sipName_509 &sipStrings_QtXmlPatterns[509]
#define sipNameNr_namespaceBindings 527
#define sipName_namespaceBindings &sipStrings_QtXmlPatterns[527]
#define sipNameNr_setMessageHandler 545
#define sipName_setMessageHandler &sipStrings_QtXmlPatterns[545]
#define sipNameNr_sip_simplewrapper 563
#define sipName_sip_simplewrapper &sipStrings_QtXmlPatterns[563]
#define sipNameNr_disconnectNotify 581
#define sipName_disconnectNotify &sipStrings_QtXmlPatterns[581]
#define sipNameNr_evaluateToString 598
#define sipName_evaluateToString &sipStrings_QtXmlPatterns[598]
#define sipNameNr_indentationDepth 615
#define sipName_indentationDepth &sipStrings_QtXmlPatterns[615]
#define sipNameNr_namespaceBinding 632
#define sipName_namespaceBinding &sipStrings_QtXmlPatterns[632]
#define sipNameNr_toNodeModelIndex 649
#define sipName_toNodeModelIndex &sipStrings_QtXmlPatterns[649]
#define sipNameNr_PreviousSibling 666
#define sipName_PreviousSibling &sipStrings_QtXmlPatterns[666]
#define sipNameNr_QSourceLocation 682
#define sipName_QSourceLocation &sipStrings_QtXmlPatterns[682]
#define sipNameNr_QXmlResultItems 698
#define sipName_QXmlResultItems &sipStrings_QtXmlPatterns[698]
#define sipNameNr_internalPointer 714
#define sipName_internalPointer &sipStrings_QtXmlPatterns[714]
#define sipNameNr_startOfSequence 730
#define sipName_startOfSequence &sipStrings_QtXmlPatterns[730]
#define sipNameNr_QXmlSerializer 746
#define sipName_QXmlSerializer &sipStrings_QtXmlPatterns[746]
#define sipNameNr_additionalData 761
#define sipName_additionalData &sipStrings_QtXmlPatterns[761]
#define sipNameNr_messageHandler 776
#define sipName_messageHandler &sipStrings_QtXmlPatterns[776]
#define sipNameNr_setUriResolver 791
#define sipName_setUriResolver &sipStrings_QtXmlPatterns[791]
#define sipNameNr_sourceLocation 806
#define sipName_sourceLocation &sipStrings_QtXmlPatterns[806]
#define sipNameNr_DocumentOrder 54
#define sipName_DocumentOrder &sipStrings_QtXmlPatterns[54]
#define sipNameNr_QXmlFormatter 821
#define sipName_QXmlFormatter &sipStrings_QtXmlPatterns[821]
#define sipNameNr_QueryLanguage 136
#define sipName_QueryLanguage &sipStrings_QtXmlPatterns[136]
#define sipNameNr_connectNotify 584
#define sipName_connectNotify &sipStrings_QtXmlPatterns[584]
#define sipNameNr_endOfSequence 835
#define sipName_endOfSequence &sipStrings_QtXmlPatterns[835]
#define sipNameNr_fromClarkName 849
#define sipName_fromClarkName &sipStrings_QtXmlPatterns[849]
#define sipNameNr_handleMessage 863
#define sipName_handleMessage &sipStrings_QtXmlPatterns[863]
#define sipNameNr_isAtomicValue 877
#define sipName_isAtomicValue &sipStrings_QtXmlPatterns[877]
#define sipNameNr_queryLanguage 891
#define sipName_queryLanguage &sipStrings_QtXmlPatterns[891]
#define sipNameNr_startDocument 905
#define sipName_startDocument &sipStrings_QtXmlPatterns[905]
#define sipNameNr_toAtomicValue 919
#define sipName_toAtomicValue &sipStrings_QtXmlPatterns[919]
#define sipNameNr_QXmlNamePool 933
#define sipName_QXmlNamePool &sipStrings_QtXmlPatterns[933]
#define sipNameNr_bindVariable 946
#define sipName_bindVariable &sipStrings_QtXmlPatterns[946]
#define sipNameNr_compareOrder 959
#define sipName_compareOrder &sipStrings_QtXmlPatterns[959]
#define sipNameNr_namespaceUri 972
#define sipName_namespaceUri &sipStrings_QtXmlPatterns[972]
#define sipNameNr_nodesByIdref 985
#define sipName_nodesByIdref &sipStrings_QtXmlPatterns[985]
#define sipNameNr_outputDevice 998
#define sipName_outputDevice &sipStrings_QtXmlPatterns[998]
#define sipNameNr_startElement 1011
#define sipName_startElement &sipStrings_QtXmlPatterns[1011]
#define sipNameNr_NextSibling 1024
#define sipName_NextSibling &sipStrings_QtXmlPatterns[1024]
#define sipNameNr_atomicValue 1036
#define sipName_atomicValue &sipStrings_QtXmlPatterns[1036]
#define sipNameNr_createIndex 1048
#define sipName_createIndex &sipStrings_QtXmlPatterns[1048]
#define sipNameNr_customEvent 1060
#define sipName_customEvent &sipStrings_QtXmlPatterns[1060]
#define sipNameNr_documentUri 1072
#define sipName_documentUri &sipStrings_QtXmlPatterns[1072]
#define sipNameNr_elementById 1084
#define sipName_elementById &sipStrings_QtXmlPatterns[1084]
#define sipNameNr_endDocument 1096
#define sipName_endDocument &sipStrings_QtXmlPatterns[1096]
#define sipNameNr_eventFilter 1108
#define sipName_eventFilter &sipStrings_QtXmlPatterns[1108]
#define sipNameNr_stringValue 1120
#define sipName_stringValue &sipStrings_QtXmlPatterns[1120]
#define sipNameNr_toClarkName 1132
#define sipName_toClarkName &sipStrings_QtXmlPatterns[1132]
#define sipNameNr_uriResolver 1144
#define sipName_uriResolver &sipStrings_QtXmlPatterns[1144]
#define sipNameNr_FirstChild 1156
#define sipName_FirstChild &sipStrings_QtXmlPatterns[1156]
#define sipNameNr_QXmlSchema 1167
#define sipName_QXmlSchema &sipStrings_QtXmlPatterns[1167]
#define sipNameNr_SimpleAxis 23
#define sipName_SimpleAxis &sipStrings_QtXmlPatterns[23]
#define sipNameNr_attributes 1178
#define sipName_attributes &sipStrings_QtXmlPatterns[1178]
#define sipNameNr_characters 1189
#define sipName_characters &sipStrings_QtXmlPatterns[1189]
#define sipNameNr_childEvent 1200
#define sipName_childEvent &sipStrings_QtXmlPatterns[1200]
#define sipNameNr_endElement 1211
#define sipName_endElement &sipStrings_QtXmlPatterns[1211]
#define sipNameNr_evaluateTo 1222
#define sipName_evaluateTo &sipStrings_QtXmlPatterns[1222]
#define sipNameNr_identifier 1233
#define sipName_identifier &sipStrings_QtXmlPatterns[1233]
#define sipNameNr_timerEvent 1244
#define sipName_timerEvent &sipStrings_QtXmlPatterns[1244]
#define sipNameNr_typedValue 1255
#define sipName_typedValue &sipStrings_QtXmlPatterns[1255]
#define sipNameNr_Attribute 1266
#define sipName_Attribute &sipStrings_QtXmlPatterns[1266]
#define sipNameNr_Namespace 1276
#define sipName_Namespace &sipStrings_QtXmlPatterns[1276]
#define sipNameNr_QXmlQuery 1286
#define sipName_QXmlQuery &sipStrings_QtXmlPatterns[1286]
#define sipNameNr_attribute 1296
#define sipName_attribute &sipStrings_QtXmlPatterns[1296]
#define sipNameNr_localName 1306
#define sipName_localName &sipStrings_QtXmlPatterns[1306]
#define sipNameNr_setColumn 1316
#define sipName_setColumn &sipStrings_QtXmlPatterns[1316]
#define sipNameNr_setSchema 1326
#define sipName_setSchema &sipStrings_QtXmlPatterns[1326]
#define sipNameNr_Document 910
#define sipName_Document &sipStrings_QtXmlPatterns[910]
#define sipNameNr_NodeKind 88
#define sipName_NodeKind &sipStrings_QtXmlPatterns[88]
#define sipNameNr_Precedes 1336
#define sipName_Precedes &sipStrings_QtXmlPatterns[1336]
#define sipNameNr_QXmlItem 1345
#define sipName_QXmlItem &sipStrings_QtXmlPatterns[1345]
#define sipNameNr_QXmlName 1354
#define sipName_QXmlName &sipStrings_QtXmlPatterns[1354]
#define sipNameNr_XQuery10 1363
#define sipName_XQuery10 &sipStrings_QtXmlPatterns[1363]
#define sipNameNr___hash__ 1372
#define sipName___hash__ &sipStrings_QtXmlPatterns[1372]
#define sipNameNr_hasError 1381
#define sipName_hasError &sipStrings_QtXmlPatterns[1381]
#define sipNameNr_isNCName 1390
#define sipName_isNCName &sipStrings_QtXmlPatterns[1390]
#define sipNameNr_namePool 1399
#define sipName_namePool &sipStrings_QtXmlPatterns[1399]
#define sipNameNr_setCodec 1408
#define sipName_setCodec &sipStrings_QtXmlPatterns[1408]
#define sipNameNr_setFocus 1417
#define sipName_setFocus &sipStrings_QtXmlPatterns[1417]
#define sipNameNr_setQuery 1426
#define sipName_setQuery &sipStrings_QtXmlPatterns[1426]
#define sipNameNr_validate 1435
#define sipName_validate &sipStrings_QtXmlPatterns[1435]
#define sipNameNr_Comment 1444
#define sipName_Comment &sipStrings_QtXmlPatterns[1444]
#define sipNameNr_Element 1016
#define sipName_Element &sipStrings_QtXmlPatterns[1016]
#define sipNameNr_Follows 1452
#define sipName_Follows &sipStrings_QtXmlPatterns[1452]
#define sipNameNr_baseUri 1460
#define sipName_baseUri &sipStrings_QtXmlPatterns[1460]
#define sipNameNr_comment 1468
#define sipName_comment &sipStrings_QtXmlPatterns[1468]
#define sipNameNr_current 1476
#define sipName_current &sipStrings_QtXmlPatterns[1476]
#define sipNameNr_isValid 1484
#define sipName_isValid &sipStrings_QtXmlPatterns[1484]
#define sipNameNr_message 1492
#define sipName_message &sipStrings_QtXmlPatterns[1492]
#define sipNameNr_resolve 1500
#define sipName_resolve &sipStrings_QtXmlPatterns[1500]
#define sipNameNr_setLine 1508
#define sipName_setLine &sipStrings_QtXmlPatterns[1508]
#define sipNameNr_Parent 1516
#define sipName_Parent &sipStrings_QtXmlPatterns[1516]
#define sipNameNr_XSLT20 1523
#define sipName_XSLT20 &sipStrings_QtXmlPatterns[1523]
#define sipNameNr___eq__ 1530
#define sipName___eq__ &sipStrings_QtXmlPatterns[1530]
#define sipNameNr___ne__ 1537
#define sipName___ne__ &sipStrings_QtXmlPatterns[1537]
#define sipNameNr_column 1544
#define sipName_column &sipStrings_QtXmlPatterns[1544]
#define sipNameNr_isNode 1551
#define sipName_isNode &sipStrings_QtXmlPatterns[1551]
#define sipNameNr_isNull 1558
#define sipName_isNull &sipStrings_QtXmlPatterns[1558]
#define sipNameNr_parent 1565
#define sipName_parent &sipStrings_QtXmlPatterns[1565]
#define sipNameNr_prefix 1572
#define sipName_prefix &sipStrings_QtXmlPatterns[1572]
#define sipNameNr_schema 1579
#define sipName_schema &sipStrings_QtXmlPatterns[1579]
#define sipNameNr_setUri 1586
#define sipName_setUri &sipStrings_QtXmlPatterns[1586]
#define sipNameNr_codec 1593
#define sipName_codec &sipStrings_QtXmlPatterns[1593]
#define sipNameNr_event 1599
#define sipName_event &sipStrings_QtXmlPatterns[1599]
#define sipNameNr_model 1605
#define sipName_model &sipStrings_QtXmlPatterns[1605]
#define sipNameNr_Text 1611
#define sipName_Text &sipStrings_QtXmlPatterns[1611]
#define sipNameNr_data 1616
#define sipName_data &sipStrings_QtXmlPatterns[1616]
#define sipNameNr_kind 1621
#define sipName_kind &sipStrings_QtXmlPatterns[1621]
#define sipNameNr_line 1626
#define sipName_line &sipStrings_QtXmlPatterns[1626]
#define sipNameNr_load 1631
#define sipName_load &sipStrings_QtXmlPatterns[1631]
#define sipNameNr_name 1636
#define sipName_name &sipStrings_QtXmlPatterns[1636]
#define sipNameNr_next 1641
#define sipName_next &sipStrings_QtXmlPatterns[1641]
#define sipNameNr_pool 1646
#define sipName_pool &sipStrings_QtXmlPatterns[1646]
#define sipNameNr_root 1651
#define sipName_root &sipStrings_QtXmlPatterns[1651]
#define sipNameNr_uri 1656
#define sipName_uri &sipStrings_QtXmlPatterns[1656]
#define sipNameNr_Is 1660
#define sipName_Is &sipStrings_QtXmlPatterns[1660]

#define sipMalloc                   sipAPI_QtXmlPatterns->api_malloc
#define sipFree                     sipAPI_QtXmlPatterns->api_free
#define sipBuildResult              sipAPI_QtXmlPatterns->api_build_result
#define sipCallMethod               sipAPI_QtXmlPatterns->api_call_method
#define sipCallProcedureMethod      sipAPI_QtXmlPatterns->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtXmlPatterns->api_call_error_handler
#define sipParseResultEx            sipAPI_QtXmlPatterns->api_parse_result_ex
#define sipParseResult              sipAPI_QtXmlPatterns->api_parse_result
#define sipParseArgs                sipAPI_QtXmlPatterns->api_parse_args
#define sipParseKwdArgs             sipAPI_QtXmlPatterns->api_parse_kwd_args
#define sipParsePair                sipAPI_QtXmlPatterns->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtXmlPatterns->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtXmlPatterns->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtXmlPatterns->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtXmlPatterns->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtXmlPatterns->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtXmlPatterns->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtXmlPatterns->api_add_exception
#define sipNoFunction               sipAPI_QtXmlPatterns->api_no_function
#define sipNoMethod                 sipAPI_QtXmlPatterns->api_no_method
#define sipAbstractMethod           sipAPI_QtXmlPatterns->api_abstract_method
#define sipBadClass                 sipAPI_QtXmlPatterns->api_bad_class
#define sipBadCatcherResult         sipAPI_QtXmlPatterns->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtXmlPatterns->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtXmlPatterns->api_bad_operator_arg
#define sipTrace                    sipAPI_QtXmlPatterns->api_trace
#define sipTransferBack             sipAPI_QtXmlPatterns->api_transfer_back
#define sipTransferTo               sipAPI_QtXmlPatterns->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtXmlPatterns->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtXmlPatterns->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtXmlPatterns->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtXmlPatterns->api_voidptr_type
#define sipGetPyObject              sipAPI_QtXmlPatterns->api_get_pyobject
#define sipGetAddress               sipAPI_QtXmlPatterns->api_get_address
#define sipGetMixinAddress          sipAPI_QtXmlPatterns->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtXmlPatterns->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtXmlPatterns->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtXmlPatterns->api_call_hook
#define sipEndThread                sipAPI_QtXmlPatterns->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtXmlPatterns->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtXmlPatterns->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtXmlPatterns->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtXmlPatterns->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtXmlPatterns->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtXmlPatterns->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtXmlPatterns->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtXmlPatterns->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtXmlPatterns->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtXmlPatterns->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtXmlPatterns->api_convert_to_bool
#define sipReleaseType              sipAPI_QtXmlPatterns->api_release_type
#define sipConvertFromType          sipAPI_QtXmlPatterns->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtXmlPatterns->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtXmlPatterns->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtXmlPatterns->api_convert_from_enum
#define sipGetState                 sipAPI_QtXmlPatterns->api_get_state
#define sipExportSymbol             sipAPI_QtXmlPatterns->api_export_symbol
#define sipImportSymbol             sipAPI_QtXmlPatterns->api_import_symbol
#define sipFindType                 sipAPI_QtXmlPatterns->api_find_type
#define sipBytes_AsChar             sipAPI_QtXmlPatterns->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtXmlPatterns->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtXmlPatterns->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtXmlPatterns->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtXmlPatterns->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtXmlPatterns->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtXmlPatterns->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtXmlPatterns->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtXmlPatterns->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtXmlPatterns->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtXmlPatterns->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtXmlPatterns->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtXmlPatterns->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtXmlPatterns->api_get_reference
#define sipKeepReference            sipAPI_QtXmlPatterns->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtXmlPatterns->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtXmlPatterns->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtXmlPatterns->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtXmlPatterns->api_type_scope
#define sipResolveTypedef           sipAPI_QtXmlPatterns->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtXmlPatterns->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtXmlPatterns->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtXmlPatterns->api_init_mixin
#define sipExportModule             sipAPI_QtXmlPatterns->api_export_module
#define sipInitModule               sipAPI_QtXmlPatterns->api_init_module
#define sipGetInterpreter           sipAPI_QtXmlPatterns->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtXmlPatterns->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtXmlPatterns->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtXmlPatterns->api_py_type_dict
#define sipPyTypeName               sipAPI_QtXmlPatterns->api_py_type_name
#define sipGetCFunction             sipAPI_QtXmlPatterns->api_get_c_function
#define sipGetMethod                sipAPI_QtXmlPatterns->api_get_method
#define sipFromMethod               sipAPI_QtXmlPatterns->api_from_method
#define sipGetDate                  sipAPI_QtXmlPatterns->api_get_date
#define sipFromDate                 sipAPI_QtXmlPatterns->api_from_date
#define sipGetDateTime              sipAPI_QtXmlPatterns->api_get_datetime
#define sipFromDateTime             sipAPI_QtXmlPatterns->api_from_datetime
#define sipGetTime                  sipAPI_QtXmlPatterns->api_get_time
#define sipFromTime                 sipAPI_QtXmlPatterns->api_from_time
#define sipIsUserType               sipAPI_QtXmlPatterns->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtXmlPatterns->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtXmlPatterns->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtXmlPatterns->api_unicode_write
#define sipUnicodeData              sipAPI_QtXmlPatterns->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtXmlPatterns->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtXmlPatterns->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtXmlPatterns->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtXmlPatterns->api_is_derived_class
#define sipGetUserObject            sipAPI_QtXmlPatterns->api_get_user_object
#define sipSetUserObject            sipAPI_QtXmlPatterns->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtXmlPatterns->api_register_event_handler
#define sipConvertToArray           sipAPI_QtXmlPatterns->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtXmlPatterns->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtXmlPatterns->api_enable_gc
#define sipPrintObject              sipAPI_QtXmlPatterns->api_print_object
#define sipLong_AsChar              sipAPI_QtXmlPatterns->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtXmlPatterns->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtXmlPatterns->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtXmlPatterns->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtXmlPatterns->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtXmlPatterns->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtXmlPatterns->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtXmlPatterns->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtXmlPatterns->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtXmlPatterns->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtXmlPatterns->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtXmlPatterns->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtXmlPatterns->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtXmlPatterns->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtXmlPatterns->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtXmlPatterns->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtXmlPatterns->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtXmlPatterns->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtXmlPatterns->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtXmlPatterns->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtXmlPatterns->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtXmlPatterns->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtXmlPatterns->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtXmlPatterns->api_connect_rx
#define sipConvertRx                sipAPI_QtXmlPatterns->api_convert_rx
#define sipDisconnectRx             sipAPI_QtXmlPatterns->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtXmlPatterns->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtXmlPatterns->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtXmlPatterns->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtXmlPatterns->api_same_slot
#define sipSaveSlot                 sipAPI_QtXmlPatterns->api_save_slot
#define sipVisitSlot                sipAPI_QtXmlPatterns->api_visit_slot
#define sipIsPyMethod               sipAPI_QtXmlPatterns->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtXmlPatterns[];

#define sipType_QAbstractMessageHandler sipExportedTypes_QtXmlPatterns[0]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QAbstractMessageHandler;

#define sipType_QAbstractUriResolver sipExportedTypes_QtXmlPatterns[1]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QAbstractUriResolver;

#define sipType_QXmlNodeModelIndex sipExportedTypes_QtXmlPatterns[13]

#define sipType_QXmlNodeModelIndex_DocumentOrder sipExportedTypes_QtXmlPatterns[14]

#define sipType_QXmlNodeModelIndex_NodeKind sipExportedTypes_QtXmlPatterns[15]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlNodeModelIndex;

#define sipType_QAbstractXmlNodeModel sipExportedTypes_QtXmlPatterns[2]

#define sipType_QAbstractXmlNodeModel_SimpleAxis sipExportedTypes_QtXmlPatterns[3]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QAbstractXmlNodeModel;

#define sipType_QXmlItem sipExportedTypes_QtXmlPatterns[10]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlItem;

#define sipType_QAbstractXmlReceiver sipExportedTypes_QtXmlPatterns[4]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QAbstractXmlReceiver;

#define sipType_QSimpleXmlNodeModel sipExportedTypes_QtXmlPatterns[5]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QSimpleXmlNodeModel;

#define sipType_QSourceLocation sipExportedTypes_QtXmlPatterns[6]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QSourceLocation;

#define sipType_QXmlSerializer sipExportedTypes_QtXmlPatterns[21]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlSerializer;

#define sipType_QXmlFormatter sipExportedTypes_QtXmlPatterns[9]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlFormatter;

#define sipType_QXmlName sipExportedTypes_QtXmlPatterns[11]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlName;

#define sipType_QXmlNamePool sipExportedTypes_QtXmlPatterns[12]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlNamePool;

#define sipType_QXmlQuery sipExportedTypes_QtXmlPatterns[16]

#define sipType_QXmlQuery_QueryLanguage sipExportedTypes_QtXmlPatterns[17]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlQuery;

#define sipType_QXmlResultItems sipExportedTypes_QtXmlPatterns[18]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlResultItems;

#define sipType_QXmlSchema sipExportedTypes_QtXmlPatterns[19]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlSchema;

#define sipType_QXmlSchemaValidator sipExportedTypes_QtXmlPatterns[20]

extern sipClassTypeDef sipTypeDef_QtXmlPatterns_QXmlSchemaValidator;

#define sipType_QVector_0100QXmlNodeModelIndex sipExportedTypes_QtXmlPatterns[8]

extern sipMappedTypeDef sipTypeDef_QtXmlPatterns_QVector_0100QXmlNodeModelIndex;

#define sipType_QVector_0100QXmlName sipExportedTypes_QtXmlPatterns[7]

extern sipMappedTypeDef sipTypeDef_QtXmlPatterns_QVector_0100QXmlName;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtXmlPatterns;
extern sipExportedModuleDef sipModuleAPI_QtXmlPatterns;
extern sipTypeDef *sipExportedTypes_QtXmlPatterns[];

#define sipType_QObject sipImportedTypes_QtXmlPatterns_QtCore[5].it_td

#define sipType_QIODevice sipImportedTypes_QtXmlPatterns_QtCore[3].it_td

#define sipType_QByteArray sipImportedTypes_QtXmlPatterns_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtXmlPatterns_QtCore[2].it_td

#define sipType_QTimerEvent sipImportedTypes_QtXmlPatterns_QtCore[9].it_td

#define sipType_QChildEvent sipImportedTypes_QtXmlPatterns_QtCore[1].it_td

#define sipType_QMetaMethod sipImportedTypes_QtXmlPatterns_QtCore[4].it_td

#define sipType_QTextCodec sipImportedTypes_QtXmlPatterns_QtCore[8].it_td

#define sipType_QUrl sipImportedTypes_QtXmlPatterns_QtCore[10].it_td

#define sipType_QVariant sipImportedTypes_QtXmlPatterns_QtCore[11].it_td

#define sipType_QStringRef sipImportedTypes_QtXmlPatterns_QtCore[7].it_td

#define sipType_QString sipImportedTypes_QtXmlPatterns_QtCore[6].it_td

#define sipType_QtMsgType sipImportedTypes_QtXmlPatterns_QtCore[12].it_td
extern sipImportedTypeDef sipImportedTypes_QtXmlPatterns_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtXmlPatterns_QtCore[];

#define sipType_QNetworkAccessManager sipImportedTypes_QtXmlPatterns_QtNetwork[0].it_td
extern sipImportedTypeDef sipImportedTypes_QtXmlPatterns_QtNetwork[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtXmlPatterns_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtXmlPatterns_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtXmlPatterns_qt_metacast;

#endif
